@rem
@rem Copyright 2015 the original author or authors.
@rem
@rem Licensed under the Apache License, Version 2.0 (the "License");
@rem you may not use this file except in compliance with the License.
@rem You may obtain a copy of the License at
@rem
@rem      https://www.apache.org/licenses/LICENSE-2.0
@rem
@rem Unless required by applicable law or agreed to in writing, software
@rem distributed under the License is distributed on an "AS IS" BASIS,
@rem WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@rem See the License for the specific language governing permissions and
@rem limitations under the License.
@rem

@if "%DEBUG%"=="" @echo off
@rem ##########################################################################
@rem
@rem  source-formatter startup script for Windows
@rem
@rem ##########################################################################

@rem Set local scope for the variables with windows NT shell
if "%OS%"=="Windows_NT" setlocal

set DIRNAME=%~dp0
if "%DIRNAME%"=="" set DIRNAME=.
@rem This is normally unused
set APP_BASE_NAME=%~n0
set APP_HOME=%DIRNAME%..

@rem Resolve any "." and ".." in APP_HOME to make it shorter.
for %%i in ("%APP_HOME%") do set APP_HOME=%%~fi

@rem Add default JVM options here. You can also use JAVA_OPTS and SOURCE_FORMATTER_OPTS to pass JVM options to this script.
set DEFAULT_JVM_OPTS=

@rem Find java.exe
if defined JAVA_HOME goto findJavaFromJavaHome

set JAVA_EXE=java.exe
%JAVA_EXE% -version >NUL 2>&1
if %ERRORLEVEL% equ 0 goto execute

echo.
echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
echo.
echo Please set the JAVA_HOME variable in your environment to match the
echo location of your Java installation.

goto fail

:findJavaFromJavaHome
set JAVA_HOME=%JAVA_HOME:"=%
set JAVA_EXE=%JAVA_HOME%/bin/java.exe

if exist "%JAVA_EXE%" goto execute

echo.
echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME%
echo.
echo Please set the JAVA_HOME variable in your environment to match the
echo location of your Java installation.

goto fail

:execute
@rem Setup the command line

set CLASSPATH=%APP_HOME%\lib\com.liferay.source.formatter-1.0.1521.jar;%APP_HOME%\lib\diffutils-1.3.0.jar;%APP_HOME%\lib\org.apache.commons.logging-1.2.LIFERAY-PATCHED-2.jar;%APP_HOME%\lib\checkstyle-8.43.jar;%APP_HOME%\lib\qdox-2.0-M5.jar;%APP_HOME%\lib\commons-io-2.19.0.jar;%APP_HOME%\lib\commons-lang-2.6.jar;%APP_HOME%\lib\jaxen-1.1.6.jar;%APP_HOME%\lib\junit-4.13.1.jar;%APP_HOME%\lib\antlr4-runtime-4.9.2.jar;%APP_HOME%\lib\ant-1.10.14.jar;%APP_HOME%\lib\maven-artifact-3.3.9.jar;%APP_HOME%\lib\dom4j-2.1.3.jar;%APP_HOME%\lib\json-20231013.jar;%APP_HOME%\lib\reflections-0.10.2.jar;%APP_HOME%\lib\xercesImpl-2.12.2.jar;%APP_HOME%\lib\picocli-4.6.1.jar;%APP_HOME%\lib\antlr-2.7.7.jar;%APP_HOME%\lib\commons-beanutils-1.9.4.jar;%APP_HOME%\lib\guava-30.1.1-jre.jar;%APP_HOME%\lib\Saxon-HE-10.5.jar;%APP_HOME%\lib\hamcrest-core-1.3.jar;%APP_HOME%\lib\ant-launcher-1.10.14.jar;%APP_HOME%\lib\plexus-utils-3.0.22.jar;%APP_HOME%\lib\commons-lang3-3.4.jar;%APP_HOME%\lib\javassist-3.28.0-GA.jar;%APP_HOME%\lib\jsr305-3.0.2.jar;%APP_HOME%\lib\slf4j-api-1.7.32.jar;%APP_HOME%\lib\xml-apis-1.4.01.jar;%APP_HOME%\lib\commons-logging-1.2.jar;%APP_HOME%\lib\commons-collections-3.2.2.jar;%APP_HOME%\lib\failureaccess-1.0.1.jar;%APP_HOME%\lib\listenablefuture-9999.0-empty-to-avoid-conflict-with-guava.jar;%APP_HOME%\lib\checker-qual-3.8.0.jar;%APP_HOME%\lib\error_prone_annotations-2.5.1.jar;%APP_HOME%\lib\j2objc-annotations-1.3.jar


@rem Execute source-formatter
"%JAVA_EXE%" %DEFAULT_JVM_OPTS% %JAVA_OPTS% %SOURCE_FORMATTER_OPTS%  -classpath "%CLASSPATH%" com.liferay.source.formatter.SourceFormatter %*

:end
@rem End local scope for the variables with windows NT shell
if %ERRORLEVEL% equ 0 goto mainEnd

:fail
rem Set variable SOURCE_FORMATTER_EXIT_CONSOLE if you need the _script_ return code instead of
rem the _cmd.exe /c_ return code!
set EXIT_CODE=%ERRORLEVEL%
if %EXIT_CODE% equ 0 set EXIT_CODE=1
if not ""=="%SOURCE_FORMATTER_EXIT_CONSOLE%" exit %EXIT_CODE%
exit /b %EXIT_CODE%

:mainEnd
if "%OS%"=="Windows_NT" endlocal

:omega
